@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2016 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -23,9 +23,10 @@
 #include "kaddressbook_grantlee_export.h"
 #include <Akonadi/Contact/ContactViewer>
 
-namespace KAddressBookGrantlee
-{
+namespace KAddressBookGrantlee {
 class GrantleeContactFormatter;
+
+/** Grantlee-based contact viewer. */
 class KADDRESSBOOK_GRANTLEE_EXPORT GrantleeContactViewer : public Akonadi::ContactViewer
 {
     Q_OBJECT
@@ -37,7 +38,7 @@ public:
 
 private:
     QString kaddressBookAbsoluteThemePath();
-    KAddressBookGrantlee::GrantleeContactFormatter *mFormatter;
+    KAddressBookGrantlee::GrantleeContactFormatter *mFormatter = nullptr;
 };
 }
 
